@@ -1,13 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-__author__ = "chuchur"
+__author__ = "Qiu"
 
 """
 MAIL = {
     "smtp_server": "smtp.qq.com",
     "account": "123456789@qq.com",
-    "account_name": "chuchur",
+    "account_name": "qiu",
     "password": "abcdefg",
     "prot": 465,  # 587
     "debug_level": 1,
@@ -20,13 +20,13 @@ m.subject = "test title"
 m.content = "long long ago..."
 
 # 嵌入html 和 html 调用附件
-m.addfile("/home/chuchur/img/a.jpg") # cid 0
-m.addfile("/home/chuchur/img/b.jpg") # cid 1
+m.addfile("/home/qiu/img/a.jpg") # cid 0
+m.addfile("/home/qiu/img/b.jpg") # cid 1
 m.addhtml("<html><body><h1>Hello</h1>" + '<p><img src="cid:0"><img src="cid:1"></p>' + "</body></html>")
 
 # 多个收件人
 m.add_to_addr("李彦宏", "liyanhong@baidu.com")
-m.add_to_addr("马云", "jackma@alibaba.com")
+m.add_to_addr("Jack ma", "jackma@alibaba.com")
 
 # 附件
 m.addfile(filepathA)
@@ -37,7 +37,7 @@ m.send()
 
 """
 
-import smtplib, os, logging
+import smtplib, os
 from email import encoders
 from email.header import Header
 from email.mime.text import MIMEText
@@ -46,6 +46,7 @@ from email.mime.multipart import MIMEMultipart
 
 from email.utils import parseaddr, formataddr
 import mimetypes
+from ..logging import info, error
 
 
 def _format_addr(s):
@@ -53,17 +54,20 @@ def _format_addr(s):
     return formataddr((Header(name, "utf-8").encode(), addr))
 
 
-class Mail(object):
+class Client(object):
     def __init__(self, **config):
-
+        self._content = None
+        self._subject = None
         smtp_server = config.get("smtp_server")
         debug_level = config.get("debug_level", 1)
         port = config.get("port", 25)
         self._account = config.get("account", "")
         self._account_name = config.get("account_name", "")
         self._password = config.get("password", "")
-        self._server = smtplib.SMTP(smtp_server, port)
-        self._server.starttls()  # 调用starttls()方法加密
+        if not smtp_server:
+            raise ValueError("smtp_server config is required")
+        self._server = smtplib.SMTP_SSL(smtp_server, port)
+        # self._server.starttls()  # 调用starttls()方法加密
         self._server.set_debuglevel(debug_level)  # 打印出和SMTP服务器交互的所有信息
         self._msg = MIMEMultipart()
         self._to_addr = []
@@ -76,33 +80,36 @@ class Mail(object):
             password = self._password
             if account is None or password is None:
                 raise KeyError("请设置账号密码")
-            logging.info("loging...")
+            info("登录中...")
             self._server.login(account, password)
         except BaseException as e:
-            logging.error(e)
+            error(e)
             raise
 
     def send(self):
         """
         发送邮件
         """
-        self._login()
-        # msg = MIMEText(self._content, "plain", "uft-8")
-        msg = self._msg
-        msg["From"] = _format_addr("%s <%s>" % (self._account_name, self._account))
-        to = []
-        for t in self._to_addr:
-            to.append("%s <%s>" % (t["name"], t["addr"]))
-        msg["To"] = _format_addr(",".join(to))
+        try:
+            self._login()
+            # msg = MIMEText(self._content, "plain", "uft-8")
+            msg = self._msg
+            msg["From"] = _format_addr("%s <%s>" % (self._account_name, self._account))
+            to = []
+            for t in self._to_addr:
+                to.append("%s <%s>" % (t["name"], t["addr"]))
+            msg["To"] = _format_addr(",".join(to))
 
-        # 邮件标题
-        msg["Subject"] = Header(self._subject, "utf-8").encode()
+            # 邮件标题
+            msg["Subject"] = Header(self._subject, "utf-8").encode()
 
-        # 邮件正文
-        msg.attach(MIMEText(self._content, self._mime_type, "utf-8"))
-        to_addr = list(map(lambda x: x["addr"], self._to_addr))
-        self._server.sendmail(self._account, to_addr, msg.as_string())
-        self._server.quit()
+            # 邮件正文
+            msg.attach(MIMEText(self._content, self._mime_type, "utf-8"))
+            to_addr = list(map(lambda x: x["addr"], self._to_addr))
+            self._server.sendmail(self._account, to_addr, msg.as_string())
+            self._server.quit()
+        except BaseException as er:
+            error(er)
 
     def add_to_addr(self, nick, addr):
         """
@@ -129,9 +136,15 @@ class Mail(object):
         """
         index = self._file_index
         with open(filepath, "rb") as f:
-            mime_type = mimetypes.guess_type(filepath)[0]  # image/png
+            mime_type = ""
+            mime_types = mimetypes.guess_type(filepath)  # image/png
+            if len(mime_types) > 0:
+                mime_type = mime_types[0]
+            else:
+                error("无法匹配附件类型,可以尝试安装httpd服务")
+            ## 这里如果拿不到type 需要安装httpd ,dnf install httpd
             [t, n] = mime_type.split("/")
-            filename = os.path.basename(filepath)  #'a.txt'
+            filename = os.path.basename(filepath)  # 'a.txt'
             # 设置附件的MIME和文件名
             mime = MIMEBase(t, n, filename=filename)
             # 加上头信息
