@@ -150,7 +150,7 @@ class Model(metaclass=ModelMetaclass):
     @classmethod
     def use(cls, pool=None):
         cls.__pool__ = pool
-        cls.__ispg = cls.__pool__.driver == "postgres" if pool else False
+        cls.__ispg = pool.driver == "postgres" if pool else False
         return cls()
 
     def select(cls, *args):
@@ -339,7 +339,7 @@ class Model(metaclass=ModelMetaclass):
         return self
 
     def test(self):
-        return self._sql()
+        return self._sql(), self.__params__
 
     async def one(self):
         self.limit(1)
@@ -379,6 +379,8 @@ class Model(metaclass=ModelMetaclass):
 
             if matches:
                 sql = re.sub(pattern, replacement, sql)
+            # pg don not support `
+            sql = sql.replace("`", '"')
 
         return sql
 
