@@ -6,7 +6,6 @@ __author__ = "Qiu / smallerqiu@gmail.com"
 import argparse
 import asyncio
 import hashlib
-import os
 import base64
 import importlib.util
 import inspect
@@ -17,7 +16,7 @@ import time
 from urllib import parse
 from aiohttp import web, hdrs
 from aiohttp.web import Response
-from aiohttp.web_ws import WebSocketResponse, WSMsgType
+from aiohttp.web_ws import WebSocketResponse,WSMsgType
 from aiohttp.web_response import StreamResponse
 from aiohttp.web_request import Request
 from aiohttp.typedefs import LooseHeaders
@@ -157,7 +156,7 @@ class Application(object):
     def __init__(self):
         self._loop = None
         self.env = None
-        self.app: web.Application = None
+        self.app: Optional[web.Application] = None
         self._route_table = web.RouteTableDef()
         self._middleware = []
         self.config = {}
@@ -282,8 +281,13 @@ class Application(object):
     async def _init_database(self, apps):
         conf_db = self.config.get("database")
         if conf_db:
-            for db_key in conf_db:
-                apps.db[db_key] = await create_engine(**conf_db[db_key])
+            # for db_key in conf_db:
+            #     apps.db[db_key] = await create_engine(**conf_db[db_key])
+            
+            tasks = [create_engine(**conf_db[db_key]) for db_key in conf_db]
+            engines = await asyncio.gather(*tasks)
+            for db_key, engine in zip(conf_db.keys(), engines):
+                apps.db[db_key] = engine
 
     async def _init_session(self, apps):
         config = self.config or {}
